@@ -1,4 +1,6 @@
 #!/usr/bin/env python3
+# pylint:disable=no-self-use
+
 import unittest
 import base64
 import subprocess
@@ -8,20 +10,26 @@ import os
 
 
 class TestCli(unittest.TestCase):
+    """
+    Test the pypcode module command line interface
+    """
+
     def test_cli_list(self):
         subprocess.run([sys.executable, "-m", "pypcode", "-l"], check=True)
 
     def test_cli_trans(self):
-        tf = tempfile.NamedTemporaryFile(delete=False)
-        tf.write(base64.b64decode("McA5xnYRSInBg+EfigwKMAwHSP/A6+vD"))
-        tf.close()
+        with tempfile.NamedTemporaryFile(delete=False) as tf:
+            tf.write(base64.b64decode("McA5xnYRSInBg+EfigwKMAwHSP/A6+vD"))
+            tf.close()
+            path = tf.name
+
         try:
             subprocess.run(
-                [sys.executable, "-m", "pypcode", "x86:LE:64:default", tf.name],
+                [sys.executable, "-m", "pypcode", "x86:LE:64:default", path],
                 check=True,
             )
         finally:
-            os.unlink(tf.name)
+            os.unlink(path)
 
 
 if __name__ == "__main__":
